@@ -169,7 +169,7 @@ class FriendMessageEvent(object):
     async def reply_long_text(self, text, quote = False):
         MAX_PER_BLOCK = 100
         number_of_blocks = len(text) // MAX_PER_BLOCK
-        msgs = [text[i:(i+1)*MAX_PER_BLOCK] for i in range(number_of_blocks)]
+        msgs = [text[i*MAX_PER_BLOCK:(i+1)*MAX_PER_BLOCK] for i in range(number_of_blocks)]
         r = len(text) % MAX_PER_BLOCK
         if r:
             msgs.append(text[MAX_PER_BLOCK * number_of_blocks:])
@@ -197,7 +197,7 @@ class GroupMessageEvent(object):
     async def reply_long_text(self, text, quote = False):
         MAX_PER_BLOCK = 100
         number_of_blocks = len(text) // MAX_PER_BLOCK
-        msgs = [text[i:(i+1)*MAX_PER_BLOCK] for i in range(number_of_blocks)]
+        msgs = [text[i*MAX_PER_BLOCK:(i+1)*MAX_PER_BLOCK] for i in range(number_of_blocks)]
         r = len(text) % MAX_PER_BLOCK
         if r:
             msgs.append(text[MAX_PER_BLOCK * number_of_blocks:])
